@@ -1,20 +1,21 @@
 #!/usr/bin/env python
 
 import numpy as np
-import os
 from ropy.robot.ETS import ETS
-
-import spatialmath as sm
+from pathlib import Path
+import ropy as rp
 
 
 class UR5(ETS):
 
     def __init__(self):
 
-        fpath = 'ropy/models/xarco/ur/urdf/ur5_joint_limited_robot.urdf.xacro'
-        abspath = os.getcwd() + '/ropy/models/xarco/ur/urdf/'
+        mpath = Path(rp.__file__).parent
+        fpath = mpath / 'models' / 'xacro' / 'ur' / 'urdf'
+        fname = 'ur5_joint_limited_robot.urdf.xacro'
+        # abspath = fpath.absolute()
 
-        args = super(UR5, self).urdf_to_ets_args(fpath)
+        args = super(UR5, self).urdf_to_ets_args((fpath / fname).as_posix())
 
         super(UR5, self).__init__(
             args[0],
@@ -29,7 +30,7 @@ class UR5(ETS):
         for link in self.ets:
             for gi in link.geometry:
                 if gi.filename[0] != '/':
-                    gi.filename = abspath + gi.filename
+                    gi.filename = (fpath / gi.filename).as_posix()
 
     @property
     def qz(self):
